import * as ec2 from "aws-cdk-lib/aws-ec2";
import * as mwaa from "aws-cdk-lib/aws-mwaa";
import * as s3 from "aws-cdk-lib/aws-s3";
import { Construct } from "constructs";
export interface AirflowPipelineProps {
    /**
     * An environment name that is prefixed to resource names
     */
    readonly environmentName?: string;
    /**
     * The maximum number of workers that can run in the environment
     */
    readonly maxWorkerNodes?: number;
    /**
     * Log level for DagProcessing
     */
    readonly dagProcessingLogs?: string;
    /**
     * Log level for SchedulerLogs
     */
    readonly schedulerLogsLevel?: string;
    /**
     * Log level for TaskLogs
     */
    readonly taskLogsLevel?: string;
    /**
     * Log level for WorkerLogs
     */
    readonly workerLogsLevel?: string;
    /**
     * Log level for WebserverLogs
     */
    readonly webserverLogsLevel?: string;
    /**
     * Existing vpc id
     */
    readonly vpcId?: string;
    /**
     * The IP range (CIDR notation) for this VPC
     */
    readonly vpcCidr?: string;
    /**
     * S3 Bucket
     */
    readonly s3Bucket?: s3.IBucket;
    /**
     * Path to dags folder in s3 bucket. Default: 'dags'
     */
    readonly dagS3Path?: string;
    /**
     * File(s) to be uploaded to dags location in s3 bucket.
     */
    readonly dagFiles?: string[];
}
export declare class AirflowDataPipeline extends Construct {
    readonly environmentName: string;
    readonly maxWorkerNodes: number;
    readonly dagProcessingLogs: string;
    readonly schedulerLogsLevel: string;
    readonly taskLogsLevel: string;
    readonly workerLogsLevel: string;
    readonly webserverLogsLevel: string;
    readonly vpc: ec2.IVpc;
    readonly s3Bucket: s3.IBucket;
    readonly mwaaEnvironment: mwaa.CfnEnvironment;
    readonly dagS3Path: string;
    constructor(scope: Construct, id: string, props: AirflowPipelineProps);
    createVpc(scope: Construct, environmentName: string, vpcCidr: string): ec2.IVpc;
}
